@@ -9,6 +9,8 @@
 #ifndef _CONFIG_IB62x0_H
 #define _CONFIG_IB62x0_H
 
+#define CONFIG_SYS_GENERIC_BOARD
+
 /*
  * Version number information
  */
@@ -43,7 +45,6 @@
  */
 #define CONFIG_SYS_NO_FLASH		/* declare no flash (NOR/SPI) */
 #define CONFIG_SYS_MVFS
-#include <config_cmd_default.h>
 #define CONFIG_CMD_ENV
 #define CONFIG_CMD_BOOTZ
 #define CONFIG_CMD_IDE
@@ -58,9 +59,6 @@
  */
 #include "mv-common.h"
 
-#undef CONFIG_SYS_PROMPT
-#define CONFIG_SYS_PROMPT	"ib62x0 => "
-
 /*
  * Environment variables configuration
  */
