@@ -13,11 +13,9 @@
 #include "tegra124-common.h"
 
 /* High-level configuration options */
-#define V_PROMPT			"Tegra124 (Nyan-big) # "
 #define CONFIG_TEGRA_BOARD_STRING	"Google/NVIDIA Nyan-big"
 
 /* Board-specific serial config */
-#define CONFIG_SERIAL_MULTI
 #define CONFIG_TEGRA_ENABLE_UARTA
 #define CONFIG_SYS_NS16550_COM1		NV_PA_APB_UARTA_BASE
 
@@ -53,8 +51,6 @@
 #define CONFIG_LCD_ALIGNMENT	MMU_SECTION_SIZE
 
 /* SPI */
-#define CONFIG_TEGRA114_SPI		/* Compatible w/ Tegra114 SPI */
-#define CONFIG_TEGRA114_SPI_CTRLS	6
 #define CONFIG_SPI_FLASH_WINBOND
 #define CONFIG_SF_DEFAULT_MODE         SPI_MODE_0
 #define CONFIG_SF_DEFAULT_SPEED        24000000
